diff --git a/thunar/thunar-details-view.c b/thunar/thunar-details-view.c
index a22cec5674735ad1cd32d98fa8ca147871336a27..05a539bf1f6ee0d616dfe2b9e3d1d316c4a2b701 100644
--- a/thunar/thunar-details-view.c
+++ b/thunar/thunar-details-view.c
@@ -691,10 +691,15 @@ thunar_details_view_button_press_event (GtkTreeView       *tree_view,
                 gtk_tree_selection_select_path (selection, path);
             }
           gtk_tree_path_free (path);
-        }
 
-      /* open the context menu */
-      thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (details_view), event->button, event->time);
+          /* queue the menu popup */
+          thunar_standard_view_queue_popup (THUNAR_STANDARD_VIEW (details_view), event);
+        }
+      else
+        {
+          /* open the context menu */
+          thunar_standard_view_context_menu (THUNAR_STANDARD_VIEW (details_view), event->button, event->time);
+        }
 
       return TRUE;
     }